==> optaplanner-examples-6.4.0.Final-test-sources.jar: org/optaplanner/examples/cloudbalancing/app/CloudBalancingExhaustiveSearchTest.java <==
/*
 * Copyright 2014 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.examples.cloudbalancing.app;

import java.io.File;
import java.util.Collection;

import org.junit.runners.Parameterized;
import org.optaplanner.core.config.exhaustivesearch.ExhaustiveSearchType;
import org.optaplanner.examples.cloudbalancing.persistence.CloudBalancingDao;
import org.optaplanner.examples.common.app.ExhaustiveSearchTest;
import org.optaplanner.examples.common.persistence.SolutionDao;

public class CloudBalancingExhaustiveSearchTest extends ExhaustiveSearchTest {

    @Parameterized.Parameters(name = "{index}: {0} - {1}")
    public static Collection<Object[]> getSolutionFilesAsParameters() {
        return buildParameters(new CloudBalancingDao(),
                "2computers-6processes.xml",
                "3computers-9processes.xml");
    }

    public CloudBalancingExhaustiveSearchTest(File unsolvedDataFile,
            ExhaustiveSearchType exhaustiveSearchType) {
        super(unsolvedDataFile, exhaustiveSearchType);
    }

    @Override
    protected String createSolverConfigResource() {
        return CloudBalancingApp.SOLVER_CONFIG;
    }

    @Override
    protected SolutionDao createSolutionDao() {
        return new CloudBalancingDao();
    }

}

==> optaplanner-examples-7.21.0.Final-test-sources.jar: org/optaplanner/examples/cloudbalancing/app/CloudBalancingExhaustiveSearchTest.java <==
/*
 * Copyright 2014 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.examples.cloudbalancing.app;

import java.io.File;
import java.util.Collection;

import org.junit.runners.Parameterized;
import org.optaplanner.core.config.exhaustivesearch.ExhaustiveSearchType;
import org.optaplanner.examples.cloudbalancing.domain.CloudBalance;
import org.optaplanner.examples.common.app.AbstractExhaustiveSearchTest;

public class CloudBalancingExhaustiveSearchTest extends AbstractExhaustiveSearchTest<CloudBalance> {

    @Parameterized.Parameters(name = "{index}: {0} - {1}")
    public static Collection<Object[]> getSolutionFilesAsParameters() {
        return buildParameters(new CloudBalancingApp(),
                "2computers-6processes.xml",
                "3computers-9processes.xml");
    }

    public CloudBalancingExhaustiveSearchTest(File unsolvedDataFile,
            ExhaustiveSearchType exhaustiveSearchType) {
        super(new CloudBalancingApp(), unsolvedDataFile, exhaustiveSearchType);
    }

}
